@@ -13,7 +13,7 @@
 class oslFlexLexer;
 
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 
 namespace pvt {
 
@@ -349,11 +349,6 @@ protected:
     /// coercion if acceptfloat is false.
     Symbol* coerce(Symbol* sym, const TypeSpec& type, bool acceptfloat = false);
 
-    /// Return the c_str giving a human-readable name of a type, fully
-    /// accounting for exotic types like structs, etc.
-    /// N.B.: just conveniently wraps the compiler's identical method.
-    const char* type_c_str(const TypeSpec& type) const;
-
     /// Assign the struct variable named by srcsym to the struct
     /// variable named by dstsym by assigning each field individually.
     /// In the case of dstsym naming an array of structs, arrayindex
@@ -1032,19 +1027,19 @@ public:
     ASTliteral(OSLCompilerImpl* comp, int i)
         : ASTNode(literal_node, comp), m_i(i)
     {
-        m_typespec = TypeDesc::TypeInt;
+        m_typespec = TypeInt;
     }
 
     ASTliteral(OSLCompilerImpl* comp, float f)
         : ASTNode(literal_node, comp), m_f(f)
     {
-        m_typespec = TypeDesc::TypeFloat;
+        m_typespec = TypeFloat;
     }
 
     ASTliteral(OSLCompilerImpl* comp, ustring s)
         : ASTNode(literal_node, comp), m_s(s)
     {
-        m_typespec = TypeDesc::TypeString;
+        m_typespec = TypeString;
     }
 
     const char* nodetypename() const { return "literal"; }
@@ -1074,4 +1069,4 @@ private:
 
 };  // namespace pvt
 
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
